==> connectagram_1.2.11.orig.tar.gz: connectagram-1.2.11/translations/connectagram_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>ChainPattern</name>
    <message>
        <source>Chain</source>
        <translation>Corrente</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>Loading</source>
        <translation>A carregar</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pausado</translation>
    </message>
</context>
<context>
    <name>Definitions</name>
    <message>
        <source>Definitions</source>
        <translation>Definições</translation>
    </message>
    <message>
        <source>Downloading definition...</source>
        <translation>A descarregar definição...</translation>
    </message>
    <message>
        <source>Unsolved word</source>
        <translation>Palavra não solucionada</translation>
    </message>
</context>
<context>
    <name>Dictionary</name>
    <message>
        <source>Definition from Wiktionary, the free dictionary</source>
        <translation>Definição do Wikcionário, o dicionário livre</translation>
    </message>
    <message>
        <source>No definition found</source>
        <translation>Nenhuma definição encontrada</translation>
    </message>
    <message>
        <source>Unable to connect to Wiktionary</source>
        <translation>Não foi possível conectar ao Wikcionário</translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <source>Fence</source>
        <translation>Vedação</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selecione o idioma da aplicação:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma do Sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Por favor reinicie a aplicação para a alteração ao idioma surtir efeito.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Novo Jogo</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Baixo</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Médio</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Alto</translation>
    </message>
    <message>
        <source>Very High</source>
        <translation>Muito Alto</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Idioma:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Comprimento da Palavra:</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Quantidade de Palavras:</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n letra</numerusform>
            <numerusform>%n letras</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <source>Rings</source>
        <translation>Anéis</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <source>Scores</source>
        <translation>Pontuações</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Pontuação</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <source>Words</source>
        <translation>Palavras</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Comprimento</translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <source>Stairs</source>
        <translation>Escadas</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <source>Twisty</source>
        <translation>Sinuoso</translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <source>Wave</source>
        <translation>Onda</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Success</source>
        <translation>Sucesso</translation>
    </message>
    <message>
        <source>Loading</source>
        <translation>A carregar</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pausado</translation>
    </message>
    <message>
        <source>Definitions</source>
        <translation>Definições</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>Dica</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Jogo</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Novo</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Escolher...</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Detalhes</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>D&amp;ica</translation>
    </message>
    <message>
        <source>H</source>
        <translation>I</translation>
    </message>
    <message>
        <source>D&amp;efinitions</source>
        <translation>D&amp;efinições</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>Po&amp;ntuações</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Definições</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Idioma da Aplicação</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>S&amp;obre</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Sobre o &amp;Qt</translation>
    </message>
    <message>
        <source>Choose Game</source>
        <translation>Escolher Jogo</translation>
    </message>
    <message>
        <source>Game Number:</source>
        <translation>Número do Jogo:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Desculpe</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Não foi possível começar o jogo pedido.</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Sobrw</translation>
    </message>
    <message>
        <source>Connectagram</source>
        <translation>Connectagram</translation>
    </message>
    <message>
        <source>A word unscrambling game</source>
        <translation>Um jogo de reordenar palavras</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Direitos de autor &amp;copy; 2009-%1 por Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Lançado sob a licença &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>As definições provêm do &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wikcionário&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalhes</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Padrão:</translation>
    </message>
    <message>
        <source>&amp;Resume</source>
        <translation>&amp;Continuar</translation>
    </message>
</context>
</TS>

==> connectagram_1.3.3.orig.tar.gz: connectagram-1.3.3/translations/connectagram_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>ChainPattern</name>
    <message>
        <source>Chain</source>
        <translation>Corrente</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>Loading</source>
        <translation>A carregar</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pausado</translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <source>Fence</source>
        <translation>Vedação</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selecione o idioma da aplicação:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma do Sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Por favor reinicie a aplicação para a alteração ao idioma surtir efeito.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Novo Jogo</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Baixo</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Médio</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Alto</translation>
    </message>
    <message>
        <source>Very High</source>
        <translation>Muito Alto</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Idioma:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Comprimento da Palavra:</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Quantidade de Palavras:</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n letra</numerusform>
            <numerusform>%n letras</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <source>Rings</source>
        <translation>Anéis</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Pontuação</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <source>Words</source>
        <translation>Palavras</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Comprimento</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <source>Stairs</source>
        <translation>Escadas</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <source>Twisty</source>
        <translation>Sinuoso</translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <source>Wave</source>
        <translation>Onda</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Success</source>
        <translation>Sucesso</translation>
    </message>
    <message>
        <source>Loading</source>
        <translation>A carregar</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pausado</translation>
    </message>
    <message>
        <source>Definitions</source>
        <translation>Definições</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>Dica</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Jogo</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Novo</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Escolher...</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Detalhes</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>D&amp;ica</translation>
    </message>
    <message>
        <source>H</source>
        <translation>I</translation>
    </message>
    <message>
        <source>D&amp;efinitions</source>
        <translation>D&amp;efinições</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Definições</translation>
    </message>
    <message>
        <source>&amp;Dark Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Idioma da Aplicação</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>S&amp;obre</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Sobre o &amp;Qt</translation>
    </message>
    <message>
        <source>Choose Game</source>
        <translation>Escolher Jogo</translation>
    </message>
    <message>
        <source>Game Number:</source>
        <translation>Número do Jogo:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Desculpe</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Não foi possível começar o jogo pedido.</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Sobrw</translation>
    </message>
    <message>
        <source>Connectagram</source>
        <translation>Connectagram</translation>
    </message>
    <message>
        <source>A word unscrambling game</source>
        <translation>Um jogo de reordenar palavras</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Direitos de autor &amp;copy; 2009-%1 por Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Lançado sob a licença &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>As definições provêm do &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wikcionário&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalhes</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Padrão:</translation>
    </message>
</context>
</TS>
